@@ -1,7 +1,17 @@
+"""
+``update_rsscontent``
+---------------------
+
+``update_rsscontent`` should be run as a cronjob when the ``RSSContent``
+content type is used -- the content type itself does not update the
+feed by itself.
+"""
+
 from django.core.management.base import BaseCommand
 
 from feincms.content.rss.models import RSSContent
 
+
 class Command(BaseCommand):
     help = "Run this as a cronjob."
 
@@ -13,4 +23,3 @@ class Command(BaseCommand):
                     content.cache_content(date_format=date_format)
                 else:
                     content.cache_content()
-
