@@ -2,9 +2,15 @@
 # coding=utf-8
 # ------------------------------------------------------------------------
 
+import logging
+
 from django import template
+from django.conf import settings
 from django.template.loader import render_to_string
 
+from feincms.utils import get_singleton, get_singleton_url
+
+
 register = template.Library()
 
 
@@ -16,12 +22,14 @@ def _render_content(content, **kwargs):
     if request is not None:
         level = getattr(request, 'feincms_render_level', 0)
         if level > 10:
-            # TODO: Log this
+            logging.getLogger('feincms').error(
+                'Refusing to render %r, render level is already %s' % (
+                    content, level))
             return
         setattr(request, 'feincms_render_level', level + 1)
 
-    if (request and request.COOKIES.get('frontend_editing', False) and\
-            hasattr(content, 'fe_render')):
+    if (request and request.COOKIES.get('frontend_editing', False)
+            and hasattr(content, 'fe_render')):
         r = content.fe_render(**kwargs)
     else:
         r = content.render(**kwargs)
@@ -34,7 +42,7 @@ def _render_content(content, **kwargs):
 
 
 @register.simple_tag(takes_context=True)
-def feincms_render_region(context, feincms_object, region, request):
+def feincms_render_region(context, feincms_object, region, request=None):
     """
     {% feincms_render_region feincms_page "main" request %}
     """
@@ -43,7 +51,7 @@ def feincms_render_region(context, feincms_object, region, request):
 
 
 @register.simple_tag(takes_context=True)
-def feincms_render_content(context, content, request):
+def feincms_render_content(context, content, request=None):
     """
     {% feincms_render_content content request %}
     """
@@ -64,14 +72,21 @@ def feincms_frontend_editing(cms_obj, request):
 
     return u''
 
+
 @register.inclusion_tag('admin/feincms/content_type_selection_widget.html', takes_context=True)
 def show_content_type_selection_widget(context, region):
     """
     {% show_content_type_selection_widget region %}
     """
+    user = context['request'].user
     grouped = {}
     ungrouped = []
     for ct in region._content_types:
+        # Skip cts that we shouldn't be adding anyway
+        perm = ct._meta.app_label + "." + ct._meta.get_add_permission()
+        if not user.has_perm(perm):
+            continue
+
         ct_info = (ct.__name__.lower(), ct._meta.verbose_name)
         if hasattr(ct, 'optgroup'):
             if ct.optgroup in grouped:
@@ -81,3 +96,21 @@ def show_content_type_selection_widget(context, region):
         else:
             ungrouped.append(ct_info)
     return {'grouped': grouped, 'ungrouped': ungrouped}
+
+
+@register.assignment_tag
+def feincms_load_singleton(template_key, cls=None):
+    """
+    {% feincms_load_singleton template_key %} -- return a FeinCMS
+    Base object which uses a Template with singleton=True.
+    """
+    return get_singleton(template_key, cls, raise_exception=settings.DEBUG)
+
+
+@register.simple_tag
+def feincms_singleton_url(template_key, cls=None):
+    """
+    {% feincms_singleton_url template_key %} -- return the URL of a FeinCMS
+    Base object which uses a Template with singleton=True.
+    """
+    return get_singleton_url(template_key, cls, raise_exception=settings.DEBUG)
